print('Thanks for you use the intting')
print('Email:a1234567890001919@outlook.com')
import intting.operating
import intting.transformation